==> Sah-Schemas-Perl-0.028.tar.gz: Sah-Schemas-Perl-0.028/lib/Sah/Schema/perl/modname_with_optional_ver.pm <==
package Sah::Schema::perl::modname_with_optional_ver;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-05-07'; # DATE
our $DIST = 'Sah-Schemas-Perl'; # DIST
our $VERSION = '0.028'; # VERSION

our $schema = [str => {
    summary => 'Perl module name (e.g. Foo::Bar) with optional version number suffix (e.g. Foo::Bar@0.001)',
    match => '\A[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_0-9]+)*(@[0-9][0-9A-Za-z]*(\\.[0-9A-Za-z_]+)*)?\z',
    'x.perl.coerce_rules' => [
        'From_str::normalize_perl_modname',
    ],

    # provide a default completion which is from list of installed perl distributions
    'x.completion' => 'perl_modname',

    examples => [
        {value=>'', valid=>0},
        {value=>'Foo-Bar', valid=>1, validated_value=>'Foo::Bar'},
        {value=>'Foo::Bar', valid=>1},
        {value=>'Foo-Bar@1.0.0', valid=>1, validated_value=>'Foo::Bar@1.0.0'},
        {value=>'Foo::Bar@1.0.0', valid=>1},
        {value=>'Foo-Bar@0.5_001', valid=>1, validated_value=>'Foo::Bar@0.5_001'},
        {value=>'Foo::Bar@0.5_001', valid=>1},
        {value=>'Foo::Bar@a', valid=>0},
    ],

}, {}];

1;
# ABSTRACT: Perl module name (e.g. Foo::Bar) with optional version number suffix (e.g. Foo::Bar@0.001)

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::Schema::perl::modname_with_optional_ver - Perl module name (e.g. Foo::Bar) with optional version number suffix (e.g. Foo::Bar@0.001)

=head1 VERSION

This document describes version 0.028 of Sah::Schema::perl::modname_with_optional_ver (from Perl distribution Sah-Schemas-Perl), released on 2020-05-07.

=head1 SYNOPSIS

Using with L<Data::Sah>:

 use Data::Sah qw(gen_validator);
 my $vdr = gen_validator("perl::modname_with_optional_ver*");
 say $vdr->($data) ? "valid" : "INVALID!";

 # Data::Sah can also create a validator to return error message, coerced value,
 # even validators in other languages like JavaScript, from the same schema.
 # See its documentation for more details.

Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):

 package MyApp;
 our %SPEC;
 $SPEC{myfunc} = {
     v => 1.1,
     summary => 'Routine to do blah ...',
     args => {
         arg1 => {
             summary => 'The blah blah argument',
             schema => ['perl::modname_with_optional_ver*'],
         },
         ...
     },
 };
 sub myfunc {
     my %args = @_;
     ...
 }

Sample data:

 ""  # INVALID

 "Foo-Bar"  # valid, becomes "Foo::Bar"

 "Foo::Bar"  # valid

 "Foo-Bar\@1.0.0"  # valid, becomes "Foo::Bar\@1.0.0"

 "Foo::Bar\@1.0.0"  # valid

 "Foo-Bar\@0.5_001"  # valid, becomes "Foo::Bar\@0.5_001"

 "Foo::Bar\@0.5_001"  # valid

 "Foo::Bar\@a"  # INVALID

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Perl>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Perl>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Perl>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2019, 2018, 2017, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Sah-Schemas-Perl-0.029.tar.gz: Sah-Schemas-Perl-0.029/lib/Sah/Schema/perl/modname_with_optional_ver.pm <==
package Sah::Schema::perl::modname_with_optional_ver;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-05-08'; # DATE
our $DIST = 'Sah-Schemas-Perl'; # DIST
our $VERSION = '0.029'; # VERSION

our $schema = [str => {
    summary => 'Perl module name (e.g. Foo::Bar) with optional version number suffix (e.g. Foo::Bar@0.001)',
    match => '\A[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_0-9]+)*(@[0-9][0-9A-Za-z]*(\\.[0-9A-Za-z_]+)*)?\z',
    'x.perl.coerce_rules' => [
        'From_str::normalize_perl_modname',
    ],

    # provide a default completion which is from list of installed perl distributions
    'x.completion' => 'perl_modname',

    examples => [
        {value=>'', valid=>0},
        {value=>'Foo-Bar', valid=>1, validated_value=>'Foo::Bar'},
        {value=>'Foo::Bar', valid=>1},
        {value=>'Foo-Bar@1.0.0', valid=>1, validated_value=>'Foo::Bar@1.0.0'},
        {value=>'Foo::Bar@1.0.0', valid=>1},
        {value=>'Foo-Bar@0.5_001', valid=>1, validated_value=>'Foo::Bar@0.5_001'},
        {value=>'Foo::Bar@0.5_001', valid=>1},
        {value=>'Foo::Bar@a', valid=>0},
    ],

}, {}];

1;
# ABSTRACT: Perl module name (e.g. Foo::Bar) with optional version number suffix (e.g. Foo::Bar@0.001)

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::Schema::perl::modname_with_optional_ver - Perl module name (e.g. Foo::Bar) with optional version number suffix (e.g. Foo::Bar@0.001)

=head1 VERSION

This document describes version 0.029 of Sah::Schema::perl::modname_with_optional_ver (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.

=head1 SYNOPSIS

Using with L<Data::Sah>:

 use Data::Sah qw(gen_validator);
 my $vdr = gen_validator("perl::modname_with_optional_ver*");
 say $vdr->($data) ? "valid" : "INVALID!";

 # Data::Sah can also create a validator to return error message, coerced value,
 # even validators in other languages like JavaScript, from the same schema.
 # See its documentation for more details.

Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):

 package MyApp;
 our %SPEC;
 $SPEC{myfunc} = {
     v => 1.1,
     summary => 'Routine to do blah ...',
     args => {
         arg1 => {
             summary => 'The blah blah argument',
             schema => ['perl::modname_with_optional_ver*'],
         },
         ...
     },
 };
 sub myfunc {
     my %args = @_;
     ...
 }

Sample data:

 undef  # INVALID

 undef  # valid

 undef  # valid

 undef  # valid

 undef  # valid

 undef  # valid

 undef  # valid

 undef  # INVALID

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Perl>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Perl>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Perl>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2019, 2018, 2017, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
